@@ -131,6 +131,18 @@ class Account(Entity):
             return []
         return [Zone(data['id'], data, api=self.api) for data in result]
 
+    def get_setting(self, setting_name):
+        """:obj:`Setting`: Finds a setting by its name.
+
+        Args:
+            setting_name (string): name of the setting. Has to be a root level entry
+        """
+        return self.api.call("GET", "/accounts/{}/settings/{}".format(self._id, setting_name))
+
+    def get_settings(self):
+        """:obj:`dict`: Fetch a all settings in the account."""
+        return self.api.call("GET", "/accounts/{}/settings".format(self._id))
+
     @property
     def email(self):
         """str: Account e-mail address.
