@@ -19,7 +19,7 @@ class Alert(object):
         return "<Alert: {} {}>".format(self._id, self._data.get("name", ""))
 
     def __eq__(self, obj):
-        return isinstance(obj, Alert) and obj._id == self._id
+        return isinstance(obj, Alert) and obj._id == self._id and obj.level == self.level
 
     @property
     def attributes(self):
