@@ -7,16 +7,18 @@ class Entity(object):
     """Base entity abstraction with common methods to update and push data the the API
     """
 
-    def __init__(self, _id, _data, api=None, update_threshold=30):
+    def __init__(self, _id, _data=None, api=None, update_threshold=30):
         self._id = _id
         self._data = _data
         self._last_updated = None
         self._update_threshold = update_threshold
-        if _data is None:
-            self.update()
         if api is None:
             api = default_api
         self.api = api
+        if _data is None:
+            self.update()
+        else:
+            self._last_updated = time.time()
 
     def _make_url(self):
         """Makes the base url for each entity and uses it for api requests.
